pub struct CapabilityRootDiscovery {
pub id: String,
pub path: PathUri,
pub plugin: Option<DiscoveredPluginFiles>,
pub skills: Vec<DiscoveredSkillFiles>,
pub namespace_manifests: Vec<CapabilityTextFile>,
pub warnings: Vec<String>,
pub error: Option<String>,
}Expand description
Manifest bundle for one selected root.
Discovery failures are root-local so one broken package does not discard valid siblings.
Fields
id: Stringpath: PathUriplugin: Option<DiscoveredPluginFiles>skills: Vec<DiscoveredSkillFiles>namespace_manifests: Vec<CapabilityTextFile>Plugin manifests found while scanning the root, used to namespace nested skills.
warnings: Vec<String>error: Option<String>Trait Implementations
Sourceimpl Clone for CapabilityRootDiscovery
impl Clone for CapabilityRootDiscovery
Sourcefn clone(&self) -> CapabilityRootDiscovery
fn clone(&self) -> CapabilityRootDiscovery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapabilityRootDiscovery
impl Debug for CapabilityRootDiscovery
Sourceimpl<'de> Deserialize<'de> for CapabilityRootDiscovery
impl<'de> Deserialize<'de> for CapabilityRootDiscovery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CapabilityRootDiscovery
Sourceimpl PartialEq for CapabilityRootDiscovery
impl PartialEq for CapabilityRootDiscovery
Sourceimpl Serialize for CapabilityRootDiscovery
impl Serialize for CapabilityRootDiscovery
impl StructuralPartialEq for CapabilityRootDiscovery