pub struct EnvironmentStatus {
pub status: EnvironmentStatusKind,
}Expand description
Status returned by an initialized exec-server connection.
The response is intentionally small today. New status details can be added without changing the method used by clients to verify that an initialized exec-server connection is still responsive.
Fields
status: EnvironmentStatusKindTrait Implementations
Sourceimpl Clone for EnvironmentStatus
impl Clone for EnvironmentStatus
Sourcefn clone(&self) -> EnvironmentStatus
fn clone(&self) -> EnvironmentStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnvironmentStatus
impl Debug for EnvironmentStatus
Sourceimpl<'de> Deserialize<'de> for EnvironmentStatus
impl<'de> Deserialize<'de> for EnvironmentStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EnvironmentStatus
Sourceimpl PartialEq for EnvironmentStatus
impl PartialEq for EnvironmentStatus
Sourceimpl Serialize for EnvironmentStatus
impl Serialize for EnvironmentStatus
impl StructuralPartialEq for EnvironmentStatus